@@ -13,12 +13,15 @@ def bmcompiler_parser():
                                 prog            = "python -m stools")
 
     
-    parser.add_argument("--method", type=str,help="method: upload, list, return, token", required=True, choices=['token', 'upload', 'list', 'return'])
+    parser.add_argument("--method", type=str,help="method: upload, list, return, token, upload_zip, upload_dir", 
+            required=True, choices=['token', 'upload', 'list', 'return', 'upload_zip', 'upload_dir'])
     parser.add_argument("--csv_file", type=str,help="csv file, the file must named 'text_masks.csv'")
     parser.add_argument("--profile_file", type=str,help="profile file, the file must named 'profile.txt'")
     parser.add_argument("--temporary-token", type=str,help="nas dir. Attention : \n \
         1. temporary-token is a token given by Sophon official people for delivering files with time limition. \n ")
     parser.add_argument("--team_id", type=str, help='team id')
+    parser.add_argument("--zip_dir", type=str, help='zip dir')
+    parser.add_argument("--dir", type=str, help='dir')
     return parser
 
 def main():
@@ -37,4 +40,9 @@ def main():
     if a.method == 'return':
         util.return_result_with_token(a.temporary_token)
     
+    if a.method == 'upload_zip':
+        util.upload_zip_with_token(a.temporary_token, a.zip_dir)
+
+    if a.method == 'upload_dir':
+        util.upload_dir_with_token(a.temporary_token, a.dir)
 
